SEQTaRget-package: SEQTaRget: Sequential Trial Emulation

SEQTaRget-packageR Documentation

SEQTaRget: Sequential Trial Emulation

Description

logo

Implementation of sequential trial emulation for the analysis of observational databases. The 'SEQTaRget' software accommodates time-varying treatments and confounders, as well as binary and failure time outcomes. 'SEQTaRget' allows to compare both static and dynamic strategies, can be used to estimate observational analogs of intention-to-treat and per-protocol effects, and can adjust for potential selection bias induced by losses-to-follow-up. (Paper to come).

Author(s)

Maintainer: Ryan O'Dea ryan.odea@psi.ch (ORCID)

Authors:

Other contributors:

  • The President and Fellows of Harvard College (ROR) [copyright holder]

See Also

Useful links:


SEQTaRget documentation built on May 21, 2026, 9:07 a.m.