| SEQdata.LTFU | R Documentation |
SEQuential()Simulated lost-to-followup example data for SEQuential()
SEQdata.LTFU
A dataframe with 54,687 rows and 13 columns:
Integer: Unique ID emulating individual patients
Integer: Time of observation, always begins at 0, max time of 59; however, if lost-to-followup, time is truncated at a random point
Binary: eligibility criteria for timepoints
Binary: If an outcome is observed at this time point
Binary: If treatment is observed at this time point
Binary: Sex of the emulated patient
Numeric: Normal random variable from N(10,5)
Numeric: 4% continuously increase from U(0, 1)
Numeric: 2% continuously decrease from U(9, 10)
Binary: Once one, always one variable emulating an excuse for treatment switch
Binary: Once one, always one variable emulating an excuse for treatment switch
Binary: Flag for losing a simulated ID to followup, if 1 there are no more records of the ID afterwards
Binary: emulates columns which are eligible to entering into censoring models (e.g. if you want to limit columns for the LTFU model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.