Learn R Programming

SEQTaRget (version 1.3.6)

SEQopts-class: An S4 class of user options to feed into the SEQuential processes and estimates This class should match SEQopts in file SEQopts.R

Description

An S4 class of user options to feed into the SEQuential processes and estimates This class should match SEQopts in file SEQopts.R

Arguments