Skip to contents

Function to return competing event models from a SEQuential object

Usage

compevent(object)

Arguments

object

SEQoutput object

Value

A fastglm object, or a named list of fastglm objects when subgroups are specified