dot-coef_table: Print a coefficient table from a cleaned fastglm object

.coef_tableR Documentation

Print a coefficient table from a cleaned fastglm object

Description

Print a coefficient table from a cleaned fastglm object

Usage

.coef_table(model)

Arguments

model

a fastglm object (may have row-level vectors stripped)


SEQTaRget documentation built on May 21, 2026, 9:07 a.m.