Generic function to format a dataset for hazard ratio calculation
Source:R/internal_hazard.R
internal.hazard.RdGeneric function to format a dataset for hazard ratio calculation

R/internal_hazard.R
internal.hazard.RdGeneric function to format a dataset for hazard ratio calculation