km_data: Function to return survival data from a SEQuential object

View source: R/class_methods.R

km_dataR Documentation

Function to return survival data from a SEQuential object

Description

Function to return survival data from a SEQuential object

Usage

km_data(object)

Arguments

object

SEQoutput object

Value

A data frame of survival values, or a named list of data frames when subgroups are specified


SEQTaRget documentation built on May 21, 2026, 9:07 a.m.