Function to return competing event models from a SEQuential object
Source:R/class_methods.R
compevent.RdFunction to return competing event models from a SEQuential object

R/class_methods.R
compevent.RdFunction to return competing event models from a SEQuential object