compevent: Function to return competing event models from a SEQuential...

View source: R/class_methods.R

compeventR Documentation

Function to return competing event models from a SEQuential object

Description

Function to return competing event models from a SEQuential object

Usage

compevent(object)

Arguments

object

SEQoutput object

Value

A fastglm object, or a named list of fastglm objects when subgroups are specified


SEQTaRget documentation built on May 21, 2026, 9:07 a.m.