View source: R/class_methods.R
| compevent | R Documentation |
Function to return competing event models from a SEQuential object
compevent(object)
object |
SEQoutput object |
A fastglm object, or a named list of fastglm objects when subgroups are specified
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.