Skip to contents

Function to return survival data from a SEQuential object

Usage

km_data(object)

Arguments

object

SEQoutput object

Value

A data frame of survival values, or a named list of data frames when subgroups are specified