R/class_methods.R
km_data.Rd
Function to return survival data from a SEQuential object
km_data(object)
SEQoutput object
A data frame of survival values, or a named list of data frames when subgroups are specified